==> hoteldruid-mod-de_1.3.2-1.tar.gz: de/gestione_utenti.php <==
<?php

switch ($messaggio) {

case "Il <b>nome</b> dell'utente":  		$messaggio = "Der <b>Name</b> des Benutzers"; break;
case "verrà cambiato da":  			$messaggio = "wird ge&auml;ndert von"; break;
case "a":  					$messaggio = "zu"; break;
case "Il <b>login</b> dell'utente":  		$messaggio = "Das <b>Login</b> des Benutzers"; break;
case "password conservata in chiaro":  		$messaggio = "Passwort in einfachem Text gespeichert"; break;
case "password conservata criptata con md5":  	$messaggio = "Passwort mit md5 verschl&uuml;sselt gespeichert"; break;
case "password conservata criptata con mcrypt":	$messaggio = "Passwort mit mycrypt verschl&uuml;sselt gespeichert"; break;
case "password conservata criptata con mhash":	$messaggio = "Passwort mit myhash verschl&uuml;sselt gespeichert"; break;
case "disabilitato":  				$messaggio = "deaktiviert"; break;
case "Inserisci una nuova password":  		$messaggio = "Neues Passwort eingeben"; break;
case "Ripeti la password":  			$messaggio = "Passwort wiederholen"; break;
case "Continua":  				$messaggio = "Weiter"; break;
case "Torna indietro":  			$messaggio = "Zur&uuml;ck"; break;
case "<div style=\"display: inline; color: red;\">Esiste già</div> un utente chiamato":	$messaggio = "<div style=\"display: inline; color: red;\">Already exists</div> an user called"; break;
case "Nuova password dell'utente":  		$messaggio = "Neues Passwort f&uuml;r Benutzer"; break;
case "<div style=\"display: inline; color: red;\">non</div> inserita correttamente":	$messaggio = "<div style=\"display: inline; color: red;\">not</div> inserted correctly"; break;
case "<b>Non</b> è stato effettuato nessun cambiamento":	$messaggio = "Es wurde <b>nichts</b> ge&auml;ndert"; break;
case "Esiste già un utente chiamato":  		$messaggio = "Es existiert bereits ein Benutzer mit Namen"; break;
case "Le nuove password non coincidono":  	$messaggio = "Neue Passw&ouml;rter stimmen nicht &uuml;berein"; break;
case "Inserisci una nuova password per l'utente":	$messaggio = "Geben Sie ein Passwort ein f&uuml;r Benutzer"; break;
case "Nuova password":  			$messaggio = "Neues Passwort"; break;
case "Gestione degli utenti di hoteldruid":	$messaggio = "HotelDruid users management"; break;
case "N°":  					$messaggio = "Nr."; break;
case "nome":  					$messaggio = "Name"; break;
case "login":  					$messaggio = "Login"; break;
case "modifica":  				$messaggio = "&Auml;ndern"; break;
case "password criptata con md5":  		$messaggio = "Passwort mit md5 verschl&uuml;sselt"; break;
case "password criptata con mcrypt":  		$messaggio = "Passwort mit mycrypt verschl&uuml;sselt"; break;
case "password criptata con mhash":  		$messaggio = "Passwort mit myhash verschl&uuml;sselt"; break;
case "password":  				$messaggio = "Passwort"; break;
case "privilegi":  				$messaggio = "Rechte"; break;
case "Amministratore":  			$messaggio = "Administrator"; break;
case "Abilitare per usare altri utenti":  	$messaggio = "Aktivieren zur Benutzung anderer Benutzer"; break;
case "Modifica gli utenti":  			$messaggio = "Benutzer &auml;ndern"; break;
case "Aggiungi":  				$messaggio = "Hinzuf&uuml;gen"; break;
case "un nuovo utente chiamato":  		$messaggio = "ein neuer Benutzer mit Namen"; break;
case "Importa i privilegi":  			$messaggio = "Import privileges"; break;
case "dell'utente":  				$messaggio = "of user"; break;
case "del gruppo":  				$messaggio = "of group"; break;
case "dall'utente":  				$messaggio = "from user"; break;
case "Privilegi importati":  			$messaggio = "Privileges imported"; break;
case "Importa":  				$messaggio = "Import"; break;
case "gruppi":  				$messaggio = "groups"; break;
case "Aggiornati i gruppi dell'utente":  	$messaggio = "Updated groups of user"; break;
case "Gruppi dell'utente":  			$messaggio = "Groups of user"; break;
case "Nuovo gruppo":  				$messaggio = "New group"; break;
case "Esiste già un gruppo chiamato":  		$messaggio = "Already exists a group called"; break;
case "Modifica":  				$messaggio = "Modify"; break;
case "cancella":  				$messaggio = "delete"; break;
case "Si è sicuri di voler <b style=\"font-weight: normal; color: red;\">cancellare</b> l'utente":	$messaggio = "Are you sure you want to <b style=\"font-weight: normal; color: red;\">delete</b> user"; break;
case "SI":  					$messaggio = "YES"; break;
case "NO":  					$messaggio = "NO"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid-mod-de_2.1.2-1.tar.gz: de/gestione_utenti.php <==
<?php

switch ($messaggio) {

case "Il <b>nome</b> dell'utente":  		$messaggio = "Der <b>Name</b> des Benutzers"; break;
case "verrà cambiato da":  			$messaggio = "wird ge&auml;ndert von"; break;
case "a":  					$messaggio = "zu"; break;
case "Il <b>login</b> dell'utente":  		$messaggio = "Das <b>Login</b> des Benutzers"; break;
case "password conservata in chiaro":  		$messaggio = "Passwort in einfachem Text gespeichert"; break;
case "password conservata criptata con md5":  	$messaggio = "Passwort mit md5 verschl&uuml;sselt gespeichert"; break;
case "password conservata criptata con mcrypt":	$messaggio = "Passwort mit mycrypt verschl&uuml;sselt gespeichert"; break;
case "password conservata criptata con mhash":	$messaggio = "Passwort mit myhash verschl&uuml;sselt gespeichert"; break;
case "disabilitato":  				$messaggio = "deaktiviert"; break;
case "Inserisci una nuova password":  		$messaggio = "Neues Passwort eingeben"; break;
case "Ripeti la password":  			$messaggio = "Passwort wiederholen"; break;
case "Continua":  				$messaggio = "Weiter"; break;
case "Torna indietro":  			$messaggio = "Zur&uuml;ck"; break;
case "Nuova password dell'utente":  		$messaggio = "Neues Passwort f&uuml;r Benutzer"; break;
case "<b>Non</b> è stato effettuato nessun cambiamento":	$messaggio = "Es wurde <b>nichts</b> ge&auml;ndert"; break;
case "Esiste già un utente chiamato":  		$messaggio = "Es existiert bereits ein Benutzer mit Namen"; break;
case "Le nuove password non coincidono":  	$messaggio = "Neue Passw&ouml;rter stimmen nicht &uuml;berein"; break;
case "Inserisci una nuova password per l'utente":	$messaggio = "Geben Sie ein Passwort ein f&uuml;r Benutzer"; break;
case "Nuova password":  			$messaggio = "Neues Passwort"; break;
case "Gestione degli utenti di hoteldruid":	$messaggio = "HotelDruid Benutzerverwaltung"; break;
case "N°":  					$messaggio = "Nr."; break;
case "nome":  					$messaggio = "Name"; break;
case "login":  					$messaggio = "Login"; break;
case "modifica":  				$messaggio = "&Auml;ndern"; break;
case "password criptata con md5":  		$messaggio = "Passwort mit md5 verschl&uuml;sselt"; break;
case "password criptata con mcrypt":  		$messaggio = "Passwort mit mycrypt verschl&uuml;sselt"; break;
case "password criptata con mhash":  		$messaggio = "Passwort mit myhash verschl&uuml;sselt"; break;
case "password":  				$messaggio = "Passwort"; break;
case "privilegi":  				$messaggio = "Rechte"; break;
case "Abilitare per usare altri utenti":  	$messaggio = "Aktivieren zur Benutzung anderer Benutzer"; break;
case "Modifica gli utenti":  			$messaggio = "Benutzer &auml;ndern"; break;
case "Aggiungi":  				$messaggio = "Hinzuf&uuml;gen"; break;
case "un nuovo utente chiamato":  		$messaggio = "ein neuer Benutzer mit Namen"; break;
case "Importa i privilegi":  			$messaggio = "Berechtigungen importieren"; break;
case "dell'utente":  				$messaggio = "f&uuml;r Benutzer"; break;
case "del gruppo":  				$messaggio = "von Gruppe"; break;
case "dall'utente":  				$messaggio = "von Benutzer"; break;
case "Privilegi importati":  			$messaggio = "Berechtigungen importiert"; break;
case "gruppi":  				$messaggio = "Gruppen"; break;
case "Aggiornati i gruppi dell'utente":  	$messaggio = "Gruppen des Benutzers aktualisiert"; break;
case "Gruppi dell'utente":  			$messaggio = "Gruppen des Benutzers"; break;
case "Nuovo gruppo":  				$messaggio = "Neue Gruppe"; break;
case "Esiste già un gruppo chiamato":  		$messaggio = "Folgende Gruppe existiert bereits:"; break;
case "Modifica":  				$messaggio = "&Auml;ndern"; break;
case "cancella":  				$messaggio = "L&ouml;schen"; break;
case "Si è sicuri di voler <b style=\"font-weight: normal; color: red;\">cancellare</b> l'utente":	$messaggio = "Sind Sie sicher, dass Sie den folgende Benutzer <b style=\"font-weight: normal; color: red;\">l&ouml;schen</b> wollen?"; break;
case "SI":  					$messaggio = "JA"; break;
case "NO":  					$messaggio = "NEIN"; break;
case "<div style=\"display: inline; color: red;\">Esiste già</div> un utente chiamato":	$messaggio = "<div style=\"display: inline; color: red;\">Already exists</div> an user called"; break;
case "<div style=\"display: inline; color: red;\">non</div> inserita correttamente":	$messaggio = "<div style=\"display: inline; color: red;\">not</div> inserted correctly"; break;
case "Amministratore":  			$messaggio = "Administrator"; break;
case "Importa":  				$messaggio = "Import"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
